import { database } from "../services/database";
import { v4 as uuidv4 } from 'uuid';

export async function getApiKeys(req: any, res: any, next: any) {
  const userId = req.user.impersonation?.id ?? req.user.id;
  const data = await database.manyOrNone('SELECT id, label FROM "ApiKey" WHERE "userId" = $1', userId);
  res.send(data);
};

export async function createApiKey(req: any, res: any, next: any) {
  const userId = req.user.impersonation?.id ?? req.user.id;
  const keys = await database.one('SELECT count(*) FROM "ApiKey" WHERE "userId" = $1', userId);
  if (keys.count > 10) {
    res.status(403).send('Too many keys');
    return;
  }
  const label = req.body.label;
  if (!label) {
    res.status(400).send('No label is attached.');
    return;
  }

  const key = uuidv4();
  await database.none('INSERT INTO "ApiKey" (id, label, "userId") VALUES ($1, $2, $3);', [key, label, userId]);
  res.send({ label, key });
};

export async function deleteApiKey(req: any, res: any, next: any) {
  if (!req.body.key) {
    res.status(400).send('key has not been provided.');
    return;
  }
  const key = await database.one('SELECT EXISTS(SELECT 1 FROM "ApiKey" WHERE id = $1)', req.body.key);
  if (!key.exists) {
    res.status(400).send('key does not exist.');
    return;
  }

  await database.none('DELETE FROM "ApiKey" WHERE id = $1', req.body.key);
  res.send({ key: req.body.key });
};