import { database } from "../services/database";
import * as http from 'typed-rest-client/HttpClient';

export async function getTwitchRedemptions(req: any, res: any, next: any) {
  const userId = req.user.impersonation?.id ?? req.user.id;
  const account: any = await database.one('SELECT "providerAccountId" FROM "Account" WHERE "userId" = $1', userId);
  const connection: any = await database.oneOrNone('SELECT "clientId", "accessToken" FROM "Connection" WHERE "userId" = $1 AND "default" = true AND "type" = \'twitch\'', userId);
  const rest = new http.HttpClient(null);
  const resp = await rest.get('https://api.twitch.tv/helix/channel_points/custom_rewards?broadcaster_id=' + account.providerAccountId, {
    'Authorization': 'Bearer ' + connection.accessToken,
    'Client-Id': connection.clientId,
  });

  const twitch = JSON.parse(await resp.readBody());
  if (!twitch?.data) {
    console.log('Failed to fetch twitch data:', account, twitch.data);
    res.status(401).send({ error: 'Could not fetch Twitch channel redemption data.' });
    return;
  }

  res.send(twitch.data);
};

export async function getTwitchUsers(req: any, res: any) {
  const username = req.query.login?.toLowerCase();
  if (!username) {
    res.status(400).send({ user: null });
    return;
  }

  const rest = new http.HttpClient(null);
  const userId = req.user.impersonation?.id ?? req.user.id;

  const connection: any = await database.oneOrNone('SELECT "clientId", "accessToken" FROM "Connection" WHERE "userId" = $1 AND "default" = true AND "type" = \'twitch\'', userId);

  const resp = await rest.get('https://api.twitch.tv/helix/users?login=' + username, {
    'Authorization': 'Bearer ' + connection.accessToken,
    'Client-Id': connection.clientId,
  });
  const twitch = JSON.parse(await resp.readBody());
  if (!twitch?.data) {
    res.status(403).send({ user: null });
    return;
  }

  const user = twitch.data.find((u: any) => u.login == username);
  res.send({ user });
};