import express, { Express, Request } from "express";
import rateLimit from "express-rate-limit";
import helmet from "helmet";

import dotenv from "dotenv";
dotenv.config();
if (!process.env.CONNECTION_STRING) {
  throw new Error("Cannot find connection string.");
}
import { passport } from "./services/passport";

const limiter = rateLimit({
  legacyHeaders: true,
  standardHeaders: true,
  windowMs: 15 * 1000,
  limit: 8,
  max: 2,
  message: "Too many requests, please try again later.",
  keyGenerator: (req: Request) => req.ip as string,
});

const app: Express = express();
const port = process.env.PORT || 3000;

const session = require('express-session');
app.use(session({
  secret: process.env.SESSION_SECRET,
  resave: false,
  saveUninitialized: false,
  cookie: {
    maxAge: 7 * 24 * 60 * 60 * 1000,
    secure: true,
  }
}));
app.use(passport.initialize());
app.use(passport.session());

const cors = require("cors");
app.use(cors({ credentials: true, origin: true }));
app.use(express.json());
app.use(express.urlencoded());
app.use(helmet());
app.use(limiter);
app.set('trust proxy', true);

app.get('/api/auth', passport.authenticate("openidconnect", { failureRedirect: '/login' }));
app.use(require('./routes/admin.route'));
app.use(require('./routes/api-keys.route'));
app.use(require('./routes/auth.route'));
app.use(require('./routes/twitch.route'));

app.listen(port, () => {
  console.log(`[server]: Server is running at http://localhost:${port}`);
});