import { OAuthData } from "../../data/oauth";
import { database } from "./database";

export const jwt = require('jsonwebtoken');
export const passport = require('passport');

const JwtStrat = require('passport-jwt').Strategy;
const ExtractJwt = require('passport-jwt').ExtractJwt;
passport.use(new JwtStrat({
  jwtFromRequest: ExtractJwt.fromAuthHeaderAsBearerToken(),
  secretOrKey: process.env.JWT_SECRET,
}, async (jwt_payload: any, done: any) => {
  const user = await database.oneOrNone('SELECT id, name, role, "ttsDefaultVoice" FROM "User" WHERE id = $1', jwt_payload.id);

  if (user) {
    done(null, user);
  } else {
    done(null, false);
  }
}));

const OpenIDConnectStrategy = require('passport-openidconnect');

passport.use(new OpenIDConnectStrategy({
  issuer: 'https://id.twitch.tv/oauth2',
  authorizationURL: 'https://id.twitch.tv/oauth2/authorize',
  tokenURL: 'https://id.twitch.tv/oauth2/token',
  clientID: process.env.AUTH_CLIENT_ID,
  clientSecret: process.env.AUTH_CLIENT_SECRET,
  callbackURL: process.env.AUTH_REDIRECT_URI,
  scope: 'user_read ' + OAuthData['twitch'].scopes.join(' '),
},
  async (url: any, profile: any, something: any, done: any) => {
    console.log('login', 'profile:', profile, 'url', url, 'something', something);
    const account: any = await database.oneOrNone('SELECT "userId" FROM "Account" WHERE "providerAccountId" = $1', profile.id);
    if (account != null) {
      const user: any = await database.oneOrNone('SELECT id, name, role, "ttsDefaultVoice" FROM "User" WHERE id = $1', account.userId);
      if (user.name != profile.username) {
        await database.none('UPDATE "User" SET name = $1 WHERE id = $2', [profile.username, profile.id]);
        user.name = profile.username;
      }
      return done(null, user);
    }
    return done(new Error('Account does not exist.'), null);
  }
));

passport.serializeUser((user: any, done: any) => {
  if (!user)
    return done(new Error('user is null'), null);
  return done(null, user);
});

passport.deserializeUser((user: any, done: any) => {
  done(null, user);
});